snapd library

Classes

RefreshInhibit
Contains proceed-time which is the date and time after which a refresh is forced for a running snap in the next auto-refresh in RFC3339 UTC format.
Snap
SnapApp
Describes an app provided by a snap.
SnapCategory
Describes an category this snap is part of.
SnapCategoryDetails
Describes a snap category.
SnapChannel
Describes a channel available for a snap.
SnapConnection
Information on a connection between a snap plugs and slots.
SnapdChange
Gives the state of an asynchronous operation.
SnapdClient
Manages a connection to the snapd server.
SnapdConnectionsResponse
Response received when getting connections.
SnapDeclaration
Response received from snap-declaration assertions.
SnapdEntropyResponse
SnapdGenerateRecoveryKeyResponse
A class to model a generate-recovery-key response from snapd
SnapdLoginResponse
Response received when logging in.
SnapdNotice
SnapdRule
Details of a prompting rule.
SnapdRuleMask
Mask for a creating or adding a prompting rule.
SnapdStorageEncryptedResponse
Response received when getting TPM backed FDE status.
SnapdSystemInfoResponse
Response received when getting system information.
SnapdSystemRefreshInfo
Contains information about refreshes.
SnapdSystemVolume
A snapd system volume.
SnapdSystemVolumeKeySlot
A class to model the key slot on a LUKS container.
SnapdSystemVolumesResponse
A class to model responses to keyslot enumeration requests.
SnapdSystemVolumeTargetKeySlot
A class to model a targeted key slot to preform an action against.
SnapdTask
Information about a task in a SnapdChange.
SnapdTaskProgress
Progress of a SnapdTask.
SnapIcon
Image data for snap icons.
SnapMedia
Describes a piece of media associated with a snap.
SnapPlug
Information on a snap plug.
SnapPublisher
Describes a snap publisher.
SnapSlot
Information on a snap slot.

Enums

SnapConfinement
Confinement used by a snap.
SnapdAppFilter
Filter to select which apps to get from snapd.
SnapdChangeFilter
Filter to select which changes to get from snapd.
SnapdConnectionFilter
Filter to select which connections to get from snapd.
SnapdKdfType
The key derivation function type for platform key encryption.
SnapdNoticeType
SnapdRequestLifespan
SnapdRequestOutcome
SnapdStorageEncryptionStatus
The state of TPM backed FDE on the system.
SnapdSystemVolumeAuthMode
The authentication mode required to unlock a platform key slot.
SnapdSystemVolumeKeySlotType
Type of key slot.
SnapFindFilter
Filter to select which apps to return from a collection search.
SnapFindScope
Scope to search snaps.
SnapsFilter
Filter to select which apps to return from a snaps list.
SnapStatus
The current state of a snap.

Extensions

StringKebabX on String

Exceptions / Errors

SnapdException
An exception thrown by a request to snapd.