SnapConnection class

Information on a connection between a snap plugs and slots.

Annotations
  • @freezed

Constructors

SnapConnection({required SnapSlot slot, required SnapPlug plug, required String interface, @Default.new({}) Map<String, dynamic> slotAttributes, @Default.new({}) Map<String, dynamic> plugAttributes, @Default.new(false) bool manual})
const
factory
SnapConnection.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SnapConnectionCopyWith<SnapConnection>
Create a copy of SnapConnection with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interface String
no setterinherited
manual bool
no setterinherited
plug SnapPlug
no setterinherited
plugAttributes Map<String, dynamic>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slot SnapSlot
no setterinherited
slotAttributes Map<String, dynamic>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SnapConnection to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited