SnapdChange class

Gives the state of an asynchronous operation.

Annotations
  • @freezed

Constructors

SnapdChange({required String id, DateTime? spawnTime, String? kind, String? summary, String? status, @Default.new(false) bool ready, DateTime? readyTime, String? err, @Default.new([]) List<SnapdTask> tasks, @JsonKey.new(name: 'data', toJson: SnapdChange._snapNamesToJson, fromJson: SnapdChange._snapNamesFromJson) @Default.new([]) List<String> snapNames})
const
factory
SnapdChange.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SnapdChangeCopyWith<SnapdChange>
Create a copy of SnapdChange with the given fields replaced by the non-null parameter values.
no setterinherited
err String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
kind String?
no setterinherited
ready bool
no setterinherited
readyTime DateTime?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapNames List<String>
no setterinherited
spawnTime DateTime?
no setterinherited
status String?
no setterinherited
summary String?
no setterinherited
tasks List<SnapdTask>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SnapdChange to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited