SnapdTaskProgress class

Progress of a SnapdTask.

Annotations
  • @freezed

Constructors

SnapdTaskProgress({@Default.new('') String label, @Default.new(0) int done, @Default.new(0) int total})
const
factory
SnapdTaskProgress.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SnapdTaskProgressCopyWith<SnapdTaskProgress>
Create a copy of SnapdTaskProgress with the given fields replaced by the non-null parameter values.
no setterinherited
done int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
label String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SnapdTaskProgress to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited